#include "mbed.h" 
#include "TextLCD.h"
#include "PID.h"
#include "TMP102.h"
#define RATE 0.1

TextLCD lcd (D5, D4, D3, D2, D1, D0, TextLCD::LCD20x4, NC, NC, TextLCD::ST7066_ACM);         // LCD (RS,E,D4,D5,D6,D7,type, controller)
PID controller (0.0, 0.0, 0.0, RATE);                                                        // Kc, Ti, Td, interval
PwmOut co (D13);                                                                             // PWM Output for the heating element SSR
TMP102 TEMP_in (D14, D15, 0x90);                                                             // I2C TMP102 (SDA,SCL,A0 pin grounded)Inside Temperature
TMP102 TEMP_com (D14, D15, 0x92);                                                            // I2C TMP102 (SDA,SCL,A0 pin to VCC)  Compressor Temperature
DigitalIn REED (D10);                                                                        // Door Reed
DigitalIn TEMP_up (A0);                                                                      // Button for increasing the temperature
DigitalIn TEMP_down (A1);                                                                    // Button for decreasing the temperature
DigitalIn TIME_up (A2);                                                                      // Button for increasing the time
DigitalIn TIME_down (A3);                                                                    // Button for decreasing the time
DigitalIn START (A4);                                                                        // Button for starting the device
DigitalIn TIME_rst (A5);                                                                     // Button for reseting the timer
DigitalOut STARTER (D11);                                                                    // Compressor engine starter SSR
DigitalOut COMPRESSOR (D12);                                                                 // Compressor engine work load SSR
DigitalOut FAN_inside (D6);                                                                  // Inside fans' relay
DigitalOut FAN_back (D7);                                                                    // Back fan's relay
DigitalOut BUZZER (PB_13);                                                                   // Buzzer

void BOOT(void);
void LCD_hello(void);
void LCD_output(void);
void PID_setup(void);
void PID_work(void);

int main ()
{
  LCD_hello();
}

void LCD_hello (void)
{
    lcd.cls();
    lcd.locate(0,0);
    lcd.printf("TEST");
    lcd.locate(0,1);
    lcd.printf("TEST");
    lcd.locate(0,2);
    lcd.printf("TEST");
    lcd.locate(0,3);
    lcd.printf("TEST");
    wait(2);
}

void BOOT (void)
{
    if (START != 0)
    {
    }
}

void PID_setup(void)
{
    controller.setInputLimits(0.0, 80.0);               // Input from 0 C to 80 C (min,max)
    controller.setOutputLimits(0.0, 1.0);               // Pwm output from 0 % to 100 % 
    controller.setBias(0);                              // If there's a bias
    controller.setMode(AUTO_MODE);                      // Mode selection
    controller.setSetPoint(70.0);                       // Desired temperature
}

void PID_work(void)
{
    controller.setProcessValue(TEMP_in.read());         // Update the process variable
    co = controller.compute();                          // Set the new output
    wait(RATE);                                         // Wait for another loop calculation
}